tinymce.addI18n('lv',{
"Redo": "Solis uz priek\u0161u",
"Undo": "Solis atpaka\u013c",
"Cut": "Izgriezt",
"Copy": "Kop\u0113t",
"Paste": "Iel\u012bm\u0113t",
"Select all": "Iez\u012bm\u0113t visu",
"New document": "Jauns dokuments",
"Ok": "Ok",
"Cancel": "Atcelt",
"Visual aids": "Vizu\u0101l\u0101 pal\u012bdz\u012bba",
"Bold": "Treknraksts",
"Italic": "Sl\u012bpraksts",
"Underline": "Pasv\u012btrot",
"Strikethrough": "Nosv\u012btrot",
"Superscript": "Aug\u0161raksts",
"Subscript": "Apak\u0161raksts",
"Clear formatting": "No\u0146emt format\u0113jumu",
"Align left": "Pa kreisi",
"Align center": "Centr\u0113t",
"Align right": "Pa labi",
"Justify": "Gar ab\u0101m mal\u0101m",
"Bullet list": "Nenumur\u0113ts saraksts",
"Numbered list": "Numur\u0113ts saraksts",
"Decrease indent": "Samazin\u0101t atk\u0101pi",
"Increase indent": "Palielin\u0101t atk\u0101pi",
"Close": "Aizv\u0113rt",
"Formats": "Format\u0113jumi",
"Your browser doesn't support direct access to the clipboard. Please use the Ctrl+X\/C\/V keyboard shortcuts instead.": "J\u016bsu p\u0101rl\u016bkprogramma neatbalsta piek\u013cuvi starpliktuvei. L\u016bdzu, lietojiet Ctrl+X\/C\/V klaviat\u016bras sa\u012bsnes.",
"Headers": "Virsraksti",
"Header 1": "1. l\u012bme\u0146a virsraksts",
"Header 2": "2. l\u012bme\u0146a virsraksts",
"Header 3": "3. l\u012bme\u0146a virsraksts",
"Header 4": "4. l\u012bme\u0146a virsraksts",
"Header 5": "5. l\u012bme\u0146a virsraksts",
"Header 6": "6. l\u012bme\u0146a virsraksts",
"Headings": "Virsraksti",
"Heading 1": "1. l\u012bme\u0146a virsraksts",
"Heading 2": "2. l\u012bme\u0146a virsraksts",
"Heading 3": "3. l\u012bme\u0146a virsraksts",
"Heading 4": "4. l\u012bme\u0146a virsraksts",
"Heading 5": "5. l\u012bme\u0146a virsraksts",
"Heading 6": "6. l\u012bme\u0146a virsraksts",
"Div": "Div",
"Pre": "Pre",
"Code": "Kods",
"Paragraph": "Rindkopa",
"Blockquote": "Cit\u0101ts",
"Inline": "Inline elementi",
"Blocks": "Bloka elementi",
"Paste is now in plain text mode. Contents will now be pasted as plain text until you toggle this option off.": "Iel\u012bm\u0113\u0161ana vienk\u0101r\u0161\u0101 teksta re\u017e\u012bm\u0101. Saturs tiks iel\u012bm\u0113ts bez format\u0113juma l\u012bdz \u0161\u012b opcija tiks atsl\u0113gta.",
"Font Family": "Fontu saime",
"Font Sizes": "Fontu izm\u0113ri",
"Class": "Klase",
"Browse for an image": "Izv\u0113l\u0113ties att\u0113lu",
"OR": "VAI",
"Drop an image here": "Ievelciet att\u0113lu \u0161eit",
"Upload": "Aug\u0161upiel\u0101d\u0113t",
"Block": "Bloks",
"Align": "L\u012bdzin\u0101t",
"Default": "Parastais",
"Circle": "Aplis",
"Disc": "Disks",
"Square": "Kvadr\u0101ts",
"Lower Alpha": "Lat\u012b\u0146u mazie burti",
"Lower Greek": "Grie\u0137u mazie burti",
"Lower Roman": "Romie\u0161u mazie burti",
"Upper Alpha": "Lat\u012b\u0146u lielie burti",
"Upper Roman": "Romie\u0161u lielie burti",
"Anchor": "Iek\u0161\u0113j\u0101 saite",
"Name": "Nosaukums",
"Id": "Identifikators",
"Id should start with a letter, followed only by letters, numbers, dashes, dots, colons or underscores.": "Identifikatoram j\u0101s\u0101kas ar burtu, p\u0113c tam var satur\u0113t: burtus, ciparus, domuz\u012bmes, punktus, kolus vai pasv\u012btrojumz\u012bmes. ",
"You have unsaved changes are you sure you want to navigate away?": "Saturs ir labots un nav saglab\u0101ts. Vai tie\u0161\u0101m v\u0113laties atst\u0101t \u0161o lapu?",
"Restore last draft": "Atjaunot p\u0113d\u0113jo melnrakstu",
"Special character": "Speci\u0101l\u0101 rakstz\u012bme",
"Source code": "Pirmkods",
"Insert\/Edit code sample": "Ievad\u012bt\/Labot koda paraugu",
"Language": "Valoda",
"Code sample": "Koda paraugs",
"Color": "Kr\u0101sa",
"R": "R",
"G": "G",
"B": "B",
"Left to right": "No kreis\u0101s uz labo",
"Right to left": "No lab\u0101s uz kreiso",
"Emoticons": "Emocijas",
"Document properties": "Dokumenta parametri",
"Title": "Nosaukums",
"Keywords": "Atsl\u0113gv\u0101rdi",
"Description": "Apraksts",
"Robots": "Programmas",
"Author": "Autors",
"Encoding": "Kod\u0113\u0161ana",
"Fullscreen": "Pilnekr\u0101na re\u017e\u012bms",
"Action": "Darb\u012bba",
"Shortcut": "Sa\u012bsne",
"Help": "Pal\u012bdz\u012bba",
"Address": "Adrese",
"Focus to menubar": "Fokuss uz izv\u0113lni",
"Focus to toolbar": "Fokuss uz r\u012bkjoslu",
"Focus to element path": "Fokuss uz elementa ce\u013cu",
"Focus to contextual toolbar": "Fokuss uz papildizv\u0113lni",
"Insert link (if link plugin activated)": "Ievietot saiti (Ja sai\u0161u spraudnis ir akt\u012bvs)",
"Save (if save plugin activated)": "Saglab\u0101t (Ja saglab\u0101\u0161anas spraudnis ir akt\u012bvs)",
"Find (if searchreplace plugin activated)": "Atrast (Ja \"searchreplace\" spraudnis ir akt\u012bvs)",
"Plugins installed ({0}):": "Spraud\u0146i instal\u0113ti ({0}):",
"Premium plugins:": "\u012apa\u0161ie spraud\u0146i:",
"Learn more...": "Uzzin\u0101t vair\u0101k...",
"You are using {0}": "J\u016bs lietojiet {0}",
"Plugins": "Spraud\u0146i",
"Handy Shortcuts": "Paroc\u012bgi \u012bsce\u013ci",
"Horizontal line": "Horizont\u0101l\u0101 l\u012bnija",
"Insert\/edit image": "Ievietot\/labot att\u0113lu",
"Image description": "Apraksts",
"Source": "Avots",
"Dimensions": "Izm\u0113ri",
"Constrain proportions": "Saglab\u0101t malu attiec\u012bbu",
"General": "Pamata info",
"Advanced": "Papildus",
"Style": "Stils",
"Vertical space": "Vertik\u0101l\u0101 atstarpe",
"Horizontal space": "Horizont\u0101l\u0101 atstarpe",
"Border": "Apmale",
"Insert image": "Ievietot att\u0113lu",
"Image": "Att\u0113ls",
"Image list": "Att\u0113lu saraksts",
"Rotate counterclockwise": "Pagriezt pret\u0113ji pulkste\u0146a r\u0101d\u012bt\u0101ja virzienam",
"Rotate clockwise": "Pagriezt pulkste\u0146a r\u0101d\u012bt\u0101ja virzien\u0101",
"Flip vertically": "Apmest vertik\u0101li",
"Flip horizontally": "Apmest horizont\u0101li",
"Edit image": "Redi\u0123\u0113t att\u0113lu",
"Image options": "Att\u0113la parametri",
"Zoom in": "Pietuvin\u0101t",
"Zoom out": "Att\u0101lin\u0101t",
"Crop": "Apgriezt",
"Resize": "Main\u012bt izm\u0113ru",
"Orientation": "Orient\u0101cija",
"Brightness": "Gai\u0161ums",
"Sharpen": "Asums",
"Contrast": "Kontrasts",
"Color levels": "Kr\u0101su l\u012bme\u0146i",
"Gamma": "Gamma",
"Invert": "Pret\u0113j\u0101s kr\u0101sas",
"Apply": "Pielietot",
"Back": "Atgriezties",
"Insert date\/time": "Ievietot datumu\/laiku",
"Date\/time": "Datums\/laiks",
"Insert link": "Ievietot saiti",
"Insert\/edit link": "Ievietot\/labot saiti",
"Text to display": "Nosaukums",
"Url": "Adrese",
"Target": "Kur atv\u0113rt",
"None": "\u2014",
"New window": "Jaun\u0101 \u0161\u0137irkl\u012b",
"Remove link": "No\u0146emt saiti",
"Anchors": "Saites",
"Link": "Saite",
"Paste or type a link": "Iekop\u0113jiet vai ierakstiet saiti",
"The URL you entered seems to be an email address. Do you want to add the required mailto: prefix?": "J\u016bs ievad\u012bj\u0101t e-pasta adresi. Lai t\u0101 korekti darbotos, ir nepiecie\u0161ams to papildin\u0101t ar \"mailto:\" priek\u0161\u0101. Vai v\u0113laties to izdar\u012bt?",
"The URL you entered seems to be an external link. Do you want to add the required http:\/\/ prefix?": "J\u016bs ievad\u012bj\u0101t \u0101r\u0113jo saiti. Lai t\u0101 korekti darbotos, ir nepiecie\u0161ams to papildin\u0101t ar \"http:\/\/\" priek\u0161\u0101. Vai v\u0113laties to izdar\u012bt?",
"Link list": "Sai\u0161u saraksts",
"Insert video": "Ievietot video",
"Insert\/edit video": "Ievietot\/redi\u0123\u0113t video",
"Insert\/edit media": "Ievietot\/labot att\u0113lu",
"Alternative source": "Alternat\u012bvs avots",
"Poster": "Att\u0113ls",
"Paste your embed code below:": "Iekop\u0113jiet Embed kodu \u0161eit:",
"Embed": "Embed kods",
"Media": "Att\u0113ls vai video",
"Nonbreaking space": "Nedal\u0101m\u0101 atstarpe",
"Page break": "P\u0101reja uz jauno lapu",
"Paste as text": "Iel\u012bm\u0113t bez format\u0113juma",
"Preview": "Priek\u0161skat\u012bt",
"Print": "Druk\u0101t",
"Save": "Saglab\u0101t",
"Find": "Mekl\u0113t",
"Replace with": "Aizvietot ar",
"Replace": "Aizvietot",
"Replace all": "Aizvietot visu",
"Prev": "Iepriek\u0161\u0113jais",
"Next": "N\u0101kamais",
"Find and replace": "Mekl\u0113t un aizvietot",
"Could not find the specified string.": "Mekl\u0113tais teksts netika atrasts",
"Match case": "At\u0161\u0137irt lielos un mazos burtus",
"Whole words": "Tikai pilnos v\u0101rdus",
"Spellcheck": "Pareizrakst\u012bbas p\u0101rbaude",
"Ignore": "Ignor\u0113t",
"Ignore all": "Ignor\u0113t visu",
"Finish": "Pabeigt",
"Add to Dictionary": "Pievienot v\u0101rdn\u012bcai",
"Insert table": "Ievietot tabulu",
"Table properties": "Tabulas parametri",
"Delete table": "Dz\u0113st tabulu",
"Cell": "\u0160\u016bna",
"Row": "Rinda",
"Column": "Kolonna",
"Cell properties": "\u0160\u016bnas parametri",
"Merge cells": "Apvienot \u0161\u016bnas",
"Split cell": "Sadal\u012bt \u0161\u016bnas",
"Insert row before": "Jauna rinda augst\u0101k",
"Insert row after": "Jauna rinda zem\u0101k",
"Delete row": "Dz\u0113st rindu",
"Row properties": "Rindas parametri",
"Cut row": "Izgriezt rindu",
"Copy row": "Kop\u0113t rindu",
"Paste row before": "Iel\u012bm\u0113t rindu augst\u0101k",
"Paste row after": "Iel\u012bm\u0113t rindu zem\u0101k",
"Insert column before": "Jauna kolonna pa kreisi",
"Insert column after": "Jauna kolonna pa labi",
"Delete column": "Dz\u0113st kolonu",
"Cols": "Kolonnas",
"Rows": "Rindas",
"Width": "Platums",
"Height": "Augstums",
"Cell spacing": "\u0160\u016bnu atstarpe",
"Cell padding": "Iek\u0161\u0113j\u0101 atstarpe",
"Caption": "Ar virsrakstu",
"Left": "Pa kreisi",
"Center": "Centr\u0113t",
"Right": "Pa labi",
"Cell type": "\u0160\u016bnas veids",
"Scope": "Attiecin\u0101t uz",
"Alignment": "Izl\u012bdzin\u0101\u0161ana",
"H Align": "Horizont\u0101lais novietojums",
"V Align": "Vertik\u0101lais novietojums",
"Top": "Aug\u0161\u0101",
"Middle": "Pa vidu",
"Bottom": "Apak\u0161\u0101",
"Header cell": "Galvenes \u0161\u016bna",
"Row group": "Rindu grupa",
"Column group": "Kolonnu grupa",
"Row type": "Rindas veids",
"Header": "Galvene",
"Body": "Saturs",
"Footer": "K\u0101jene",
"Border color": "Apmales kr\u0101sa",
"Insert template": "Ievietot veidni",
"Templates": "Veidnes",
"Template": "Veidne",
"Text color": "Teksta kr\u0101sa",
"Background color": "Fona kr\u0101sa",
"Custom...": "Izv\u0113l\u0113ties citu...",
"Custom color": "Specifisk\u0101 kr\u0101sa",
"No color": "Nenor\u0101d\u012bt kr\u0101su",
"Table of Contents": "Saturs",
"Show blocks": "R\u0101d\u012bt blokus",
"Show invisible characters": "R\u0101d\u012bt neredzam\u0101s rakstz\u012bmes",
"Words: {0}": "V\u0101rdi: {0}",
"{0} words": "{0} v\u0101rdi",
"File": "Datne",
"Edit": "Labot",
"Insert": "Ievietot",
"View": "Skat\u012bt",
"Format": "Format\u0113t",
"Table": "Tabula",
"Tools": "R\u012bki",
"Powered by {0}": "Darb\u012bbu nodro\u0161ina {0}",
"Rich Text Area. Press ALT-F9 for menu. Press ALT-F10 for toolbar. Press ALT-0 for help": "Satura redaktors. Nospiediet ALT-F9 lai par\u0101d\u012btu izv\u0113lni, ALT-F10 - r\u012bkjoslu vai ALT-0 - pal\u012bdz\u012bbu."
});