tinymce.addI18n('sl_SI',{
"Cut": "Izre\u017ei",
"Heading 5": "Podnaslov 5",
"Header 2": "Naslov 2",
"Your browser doesn't support direct access to the clipboard. Please use the Ctrl+X\/C\/V keyboard shortcuts instead.": "Varnostne nastavitve brskalnika ne dopu\u0161\u010dajo direktnega dostopa do odlo\u017ei\u0161\u010da. Uporabite kombinacijo tipk Ctrl+X\/C\/V na tipkovnici.",
"Heading 4": "Podnaslov 4",
"Div": "Div",
"Heading 2": "Podnaslov 2",
"Paste": "Prilepi",
"Close": "Zapri",
"Font Family": "Dru\u017eina pisav",
"Pre": "Predformat",
"Align right": "Desna poravnava",
"New document": "Nov dokument",
"Blockquote": "Zamik besedila",
"Numbered list": "O\u0161tevil\u010den seznam",
"Heading 1": "Podnaslov 1",
"Headings": "Podnaslovi",
"Increase indent": "Pove\u010daj zamik",
"Formats": "Oblika",
"Headers": "Naslovi",
"Select all": "Izberi vse",
"Header 3": "Naslov 3",
"Blocks": "Grupe",
"Undo": "Razveljavi",
"Strikethrough": "Pre\u010drtano",
"Bullet list": "Ozna\u010den seznam",
"Header 1": "Naslov 1",
"Superscript": "Nadpisano",
"Clear formatting": "Odstrani oblikovanje",
"Font Sizes": "Velikosti pisave",
"Subscript": "Podpisano",
"Header 6": "Naslov 6",
"Redo": "Ponovi",
"Paragraph": "Odstavek",
"Ok": "V redu",
"Bold": "Krepko",
"Code": "Koda",
"Italic": "Le\u017ee\u010de",
"Align center": "Sredinska poravnava",
"Header 5": "Naslov 5",
"Heading 6": "Podnaslov 6",
"Heading 3": "Podnaslov 3",
"Decrease indent": "Zmanj\u0161aj zamik",
"Header 4": "Naslov 4",
"Paste is now in plain text mode. Contents will now be pasted as plain text until you toggle this option off.": "Odlagali\u0161\u010de je zdaj v tekstovnem na\u010dinu. Vsebina bo preslikana kot golo besedilo brez oblike, dokler te mo\u017enosti ne izklju\u010dite.",
"Underline": "Pod\u010drtano",
"Cancel": "Prekli\u010di",
"Justify": "Obojestranska poravnava",
"Inline": "Med besedilom",
"Copy": "Kopiraj",
"Align left": "Leva poravnava",
"Visual aids": "Vizualni pripomo\u010dki",
"Lower Greek": "Male gr\u0161ke \u010drke",
"Square": "Kvadratek",
"Default": "Privzeto",
"Lower Alpha": "Male tiskane \u010drke",
"Circle": "Pikica",
"Disc": "Kroglica",
"Upper Alpha": "Velike tiskane \u010drke",
"Upper Roman": "Velike rimske \u0161tevilke",
"Lower Roman": "Male rimske \u0161tevilke",
"Id should start with a letter, followed only by letters, numbers, dashes, dots, colons or underscores.": "Id se mora za\u010deti s \u010drko, sledijo samo \u010drke, \u0161tevilke, pomi\u0161ljaj, pike, dvopi\u010dje ali pod\u010drtaj.",
"Name": "Naziv zaznamka",
"Anchor": "Zaznamek",
"Id": "Id",
"You have unsaved changes are you sure you want to navigate away?": "Imate neshranjene spremembe. Ste prepri\u010dati, da \u017eelite zapustiti stran?",
"Restore last draft": "Obnovi zadnji osnutek",
"Special character": "Posebni znaki",
"Source code": "Izvorna koda",
"Language": "Jezik",
"Insert\/Edit code sample": "Vstavi\/Uredi vzor\u010dno kodo",
"B": "B",
"R": "R",
"G": "G",
"Color": "Barva",
"Right to left": "Od desne proti levi",
"Left to right": "Od leve proti desni",
"Emoticons": "Sme\u0161ki",
"Robots": "Robotki",
"Document properties": "Lastnosti dokumenta",
"Title": "Naslov",
"Keywords": "Klju\u010dne besede",
"Encoding": "Kodiranje",
"Description": "Opis",
"Author": "Avtor",
"Fullscreen": "\u010cez cel zaslon",
"Horizontal line": "Vodoravna \u010drta",
"Horizontal space": "Vodoravni prostor",
"Insert\/edit image": "Vstavi\/uredi sliko",
"General": "Splo\u0161no",
"Advanced": "Napredno",
"Source": "Pot",
"Border": "Obroba",
"Constrain proportions": "Obdr\u017ei razmerje",
"Vertical space": "Navpi\u010dni prostor",
"Image description": "Opis slike",
"Style": "Slog",
"Dimensions": "Dimenzije",
"Insert image": "Vnesi sliko",
"Image": "Slika",
"Zoom in": "Pove\u010daj",
"Contrast": "Kontrast",
"Back": "Nazaj",
"Gamma": "Gama",
"Flip horizontally": "Obrni vodoravno",
"Resize": "Spremeni velikost",
"Sharpen": "Izostri",
"Zoom out": "Pomanj\u0161aj",
"Image options": "Mo\u017enosti slike",
"Apply": "Uporabi",
"Brightness": "Svetlost",
"Rotate clockwise": "Zavrti v smeri urinega kazalca",
"Rotate counterclockwise": "Zavrti v nasprotni smeri urnega kazalca",
"Edit image": "Uredi sliko",
"Color levels": "Barvni nivo",
"Crop": "Obre\u017ei",
"Orientation": "Usmerjenost",
"Flip vertically": "Obrni navpi\u010dno",
"Invert": "Obrni",
"Date\/time": "Datum\/\u010das",
"Insert date\/time": "Vstavi datum\/\u010das",
"Remove link": "Odstrani povezavo",
"Url": "Povezava",
"Text to display": "Prikazno besedilo",
"Anchors": "Sidra",
"Insert link": "Vstavi povezavo",
"Link": "Povezava",
"New window": "Novo okno",
"None": "Brez",
"The URL you entered seems to be an external link. Do you want to add the required http:\/\/ prefix?": "Vne\u0161eni URL predstavlja zunanjo povezavo. Ali \u017eelite dodati \"http:\/\/\" predpono?",
"Paste or type a link": "Prilepite ali vnesite povezavo",
"Target": "Cilj",
"The URL you entered seems to be an email address. Do you want to add the required mailto: prefix?": "Vne\u0161eni URL predstavlja e-po\u0161tni naslov. Ali \u017eelite dodati potrebno \"mailto:\" predpono?",
"Insert\/edit link": "Vstavi\/uredi povezavo",
"Insert\/edit video": "Vstavi\/uredi video",
"Media": "Medij",
"Alternative source": "Nadomestni vir",
"Paste your embed code below:": "Prilepite kodo za vdelavo:",
"Insert video": "Vstavi video",
"Poster": "Poster",
"Insert\/edit media": "Vstavi\/uredi medij",
"Embed": "Vdelaj",
"Nonbreaking space": "Nedeljivi presledek",
"Page break": "Prelom strani",
"Paste as text": "Vnesi kot besedilo",
"Preview": "Predogled",
"Print": "Natisni",
"Save": "Shrani",
"Could not find the specified string.": "Iskanje ni vrnilo rezultatov.",
"Replace": "Zamenjaj",
"Next": "Naprej",
"Whole words": "Cele besede",
"Find and replace": "Poi\u0161\u010di in zamenjaj",
"Replace with": "Zamenjaj z",
"Find": "I\u0161\u010di",
"Replace all": "Zamenjaj vse",
"Match case": "Ujemanje malih in velikih \u010drk",
"Prev": "Nazaj",
"Spellcheck": "Preverjanje \u010drkovanja",
"Finish": "Zaklju\u010di",
"Ignore all": "Prezri vse",
"Ignore": "Prezri",
"Add to Dictionary": "Dodaj v slovar",
"Insert row before": "Vstavi vrstico pred",
"Rows": "Vrstice",
"Height": "Vi\u0161ina",
"Paste row after": "Prilepi vrstico za",
"Alignment": "Poravnava",
"Border color": "Barva obrobe",
"Column group": "Grupiranje stolpcev",
"Row": "Vrstica",
"Insert column before": "Vstavi stolpec pred",
"Split cell": "Razdeli celico",
"Cell padding": "Polnilo med celicami",
"Cell spacing": "Razmik med celicami",
"Row type": "Tip vrstice",
"Insert table": "Vstavi tabelo",
"Body": "Vsebina",
"Caption": "Naslov",
"Footer": "Noga",
"Delete row": "Izbri\u0161i vrstico",
"Paste row before": "Prilepi vrstico pred",
"Scope": "Obseg",
"Delete table": "Izbri\u0161i tabelo",
"H Align": "Horizontalna poravnava",
"Top": "Vrh",
"Header cell": "Celica glave",
"Column": "Stolpec",
"Row group": "Grupiranje vrstic",
"Cell": "Celica",
"Middle": "Sredina",
"Cell type": "Tip celice",
"Copy row": "Kopiraj vrstico",
"Row properties": "Lastnosti vrstice",
"Table properties": "Lastnosti tabele",
"Bottom": "Dno",
"V Align": "Vertikalna poravnava",
"Header": "Glava",
"Right": "Desno",
"Insert column after": "Vstavi stolpec za",
"Cols": "Stolpci",
"Insert row after": "Vstavi vrstico za",
"Width": "\u0160irina",
"Cell properties": "Lastnosti celice",
"Left": "Levo",
"Cut row": "Izre\u017ei vrstico",
"Delete column": "Izbri\u0161i stolpec",
"Center": "Sredinsko",
"Merge cells": "Zdru\u017ei celice",
"Insert template": "Vstavi predlogo",
"Templates": "Predloge",
"Background color": "Barva ozadja",
"Custom...": "Po meri ...",
"Custom color": "Barva po meri",
"No color": "Brezbarvno",
"Text color": "Barva besedila",
"Table of Contents": "Kazalo",
"Show blocks": "Prika\u017ei bloke",
"Show invisible characters": "Prika\u017ei skrite znake",
"Words: {0}": "Besed: {0}",
"Insert": "Vstavi",
"File": "Datoteka",
"Edit": "Uredi",
"Rich Text Area. Press ALT-F9 for menu. Press ALT-F10 for toolbar. Press ALT-0 for help": "Bogato besedilo. Pritisnite ALT-F9 za meni. Pritisnite ALT-F10 za orodno vrstico. Pritisnite ALT-0 za pomo\u010d",
"Tools": "Orodja",
"View": "Pogled",
"Table": "Tabela",
"Format": "Oblika"
});