tinymce.addI18n('ga',{
"Redo": "Athdh\u00e9an",
"Undo": "Cealaigh",
"Cut": "Gearr",
"Copy": "C\u00f3ipe\u00e1il",
"Paste": "Greamaigh",
"Select all": "Roghnaigh uile",
"New document": "C\u00e1ip\u00e9is nua",
"Ok": "OK",
"Cancel": "Cealaigh",
"Visual aids": "\u00c1iseanna amhairc",
"Bold": "Trom",
"Italic": "Iod\u00e1lach",
"Underline": "Fol\u00edne",
"Strikethrough": "L\u00edne tr\u00edd",
"Superscript": "Forscript",
"Subscript": "Foscript",
"Clear formatting": "Glan form\u00e1idi\u00fa",
"Align left": "Ail\u00ednigh ar chl\u00e9",
"Align center": "Ail\u00ednigh sa l\u00e1r",
"Align right": "Ail\u00ednigh ar dheis",
"Justify": "Comhfhadaigh",
"Bullet list": "Liosta Urchar",
"Numbered list": "Liosta Uimhrithe",
"Decrease indent": "Laghdaigh eang",
"Increase indent": "M\u00e9adaigh eang",
"Close": "D\u00fan",
"Formats": "Form\u00e1id\u00ed",
"Your browser doesn't support direct access to the clipboard. Please use the Ctrl+X\/C\/V keyboard shortcuts instead.": "N\u00ed f\u00e9idir le do bhrabhs\u00e1la\u00ed teacht go d\u00edreach ar an ngearrthaisce. Bain \u00fas\u00e1id as na haicearra\u00ed Ctrl+X\/C\/V. ",
"Headers": "Ceannt\u00e1sca",
"Header 1": "Ceannt\u00e1sc 1",
"Header 2": "Ceannt\u00e1sc 2",
"Header 3": "Ceannt\u00e1sc 3",
"Header 4": "Ceannt\u00e1sc 4",
"Header 5": "Ceannt\u00e1sc 5",
"Header 6": "Ceannt\u00e1sc 6",
"Headings": "Ceannteidil",
"Heading 1": "Ceannteideal 1",
"Heading 2": "Ceannteideal 2",
"Heading 3": "Ceannteideal 3",
"Heading 4": "Ceannteideal 4",
"Heading 5": "Ceannteideal 5",
"Heading 6": "Ceannteideal 6",
"Preformatted": "R\u00e9amhfhorm\u00e1idithe",
"Div": "Deighilt",
"Pre": "R\u00e9amh",
"Code": "C\u00f3d",
"Paragraph": "Alt",
"Blockquote": "Athfhriotal",
"Inline": "Inl\u00edne",
"Blocks": "Blocanna",
"Paste is now in plain text mode. Contents will now be pasted as plain text until you toggle this option off.": "Sa m\u00f3d gn\u00e1th-th\u00e9acs anois. Gream\u00f3far \u00e1bhar mar ghn\u00e1th-th\u00e9acs go dt\u00ed go m\u00fachfaidh t\u00fa an rogha seo.",
"Font Family": "Cl\u00f3fhoireann",
"Font Sizes": "Cl\u00f3mh\u00e9ideanna",
"Class": "Aicme",
"Browse for an image": "Brabhs\u00e1il le haghaidh \u00edomh\u00e1",
"OR": "N\u00d3",
"Drop an image here": "Scaoil \u00edomh\u00e1 anseo",
"Upload": "Uasl\u00f3d\u00e1il",
"Block": "Bloc",
"Align": "Ail\u00ednigh",
"Default": "R\u00e9amhshocr\u00fa",
"Circle": "Ciorcal",
"Disc": "Diosca",
"Square": "Cearn\u00f3g",
"Lower Alpha": "Alfa Beag",
"Lower Greek": "Litir Bheag Ghr\u00e9agach",
"Lower Roman": "Litir Bheag R\u00f3mh\u00e1nach",
"Upper Alpha": "Alfa M\u00f3r",
"Upper Roman": "Litir Mh\u00f3r R\u00f3mh\u00e1nach",
"Anchor": "Ancaire",
"Name": "Ainm",
"Id": "Aitheantas",
"Id should start with a letter, followed only by letters, numbers, dashes, dots, colons or underscores.": "N\u00ed m\u00f3r don aitheantas tos\u00fa le litir, agus gan ach litreacha, uimhreacha, daiseanna, poncanna, idirstadanna, n\u00f3 fostr\u00edoca ina dhiaidh sin.",
"You have unsaved changes are you sure you want to navigate away?": "T\u00e1 athruithe gan s\u00e1bh\u00e1il ann. An bhfuil t\u00fa cinnte gur mhaith leat imeacht amach as seo?",
"Restore last draft": "Oscail an dr\u00e9acht is d\u00e9ana\u00ed",
"Special character": "Carachtar speisialta",
"Source code": "C\u00f3d foinseach",
"Insert\/Edit code sample": "Cuir sampla c\u00f3id isteach\/in eagar",
"Language": "Teanga",
"Code sample": "Sampla c\u00f3id",
"Color": "Dath",
"R": "D",
"G": "U",
"B": "G",
"Left to right": "Cl\u00e9-go-deas",
"Right to left": "Deas-go-cl\u00e9",
"Emoticons": "Straoiseoga",
"Document properties": "Air\u00edonna na C\u00e1ip\u00e9ise",
"Title": "Teideal",
"Keywords": "Lorgfhocail",
"Description": "Cur S\u00edos",
"Robots": "R\u00f3bait",
"Author": "\u00dadar",
"Encoding": "Ionch\u00f3d\u00fa",
"Fullscreen": "L\u00e1nsc\u00e1ile\u00e1n",
"Action": "Gn\u00edomh",
"Shortcut": "Aicearra",
"Help": "Cabhair",
"Address": "Seoladh",
"Focus to menubar": "F\u00f3cas sa bharra roghchl\u00e1ir",
"Focus to toolbar": "F\u00f3cas sa bharra uirlis\u00ed",
"Focus to element path": "F\u00f3cas sa chonair eiliminte",
"Focus to contextual toolbar": "F\u00f3cas sa bharra uirlis\u00ed comhth\u00e9acs\u00fail",
"Insert link (if link plugin activated)": "Cuir nasc isteach (m\u00e1 t\u00e1 an breise\u00e1n naisc ar si\u00fal)",
"Save (if save plugin activated)": "S\u00e1bh\u00e1il (m\u00e1 t\u00e1 an breise\u00e1n s\u00e1bh\u00e1la ar si\u00fal)",
"Find (if searchreplace plugin activated)": "Aimsigh (m\u00e1 t\u00e1 an breise\u00e1n cuardaigh ar si\u00fal)",
"Plugins installed ({0}):": "Breise\u00e1in shuite\u00e1ilte ({0}):",
"Premium plugins:": "Scothbhreise\u00e1in:",
"Learn more...": "Tuilleadh eolais...",
"You are using {0}": "T\u00e1 t\u00fa ag \u00fas\u00e1id {0}",
"Plugins": "Breise\u00e1in",
"Handy Shortcuts": "Aicearra\u00ed \u00das\u00e1ideacha",
"Horizontal line": "L\u00edne chothrom\u00e1nach",
"Insert\/edit image": "Cuir \u00edomh\u00e1 isteach\/in eagar",
"Image description": "Cur s\u00edos ar an \u00edomh\u00e1",
"Source": "Foinse",
"Dimensions": "Tois\u00ed",
"Constrain proportions": "Comhr\u00e9ir faoi ghlas",
"General": "Ginear\u00e1lta",
"Advanced": "Casta",
"Style": "St\u00edl",
"Vertical space": "Sp\u00e1s ingearach",
"Horizontal space": "Sp\u00e1s cothrom\u00e1nach",
"Border": "Iml\u00edne",
"Insert image": "Cuir \u00edomh\u00e1 isteach",
"Image": "\u00cdomh\u00e1",
"Image list": "Liosta \u00edomh\u00e1nna",
"Rotate counterclockwise": "Rothlaigh ar tuathal",
"Rotate clockwise": "Rothlaigh ar deiseal",
"Flip vertically": "Cas go hingearach",
"Flip horizontally": "Cas go cothrom\u00e1nach",
"Edit image": "Cuir an \u00edomh\u00e1 in eagar",
"Image options": "Roghanna \u00edomh\u00e1",
"Zoom in": "Z\u00fam\u00e1il isteach",
"Zoom out": "Z\u00fam\u00e1il amach",
"Crop": "Bear",
"Resize": "Athraigh m\u00e9id",
"Orientation": "Treoshu\u00edomh",
"Brightness": "Gile",
"Sharpen": "G\u00e9araigh",
"Contrast": "Codarsnacht",
"Color levels": "Leibh\u00e9il datha",
"Gamma": "G\u00e1ma",
"Invert": "Inbh\u00e9artaigh",
"Apply": "Cuir i bhfeidhm",
"Back": "Siar",
"Insert date\/time": "Cuir d\u00e1ta\/am isteach",
"Date\/time": "D\u00e1ta\/am",
"Insert link": "Cuir nasc isteach",
"Insert\/edit link": "Cuir nasc isteach\/in eagar",
"Text to display": "T\u00e9acs le taispe\u00e1int",
"Url": "URL",
"Target": "Sprioc",
"None": "Dada",
"New window": "Fuinneog nua",
"Remove link": "Bain an nasc",
"Anchors": "Ancair\u00ed",
"Link": "Nasc",
"Paste or type a link": "Greamaigh n\u00f3 cl\u00f3scr\u00edobh nasc",
"The URL you entered seems to be an email address. Do you want to add the required mailto: prefix?": "Is seoladh r\u00edomhphoist \u00e9 an URL a chuir t\u00fa isteach. An bhfuil fonn ort an r\u00e9im\u00edr riachtanach mailto: a chur leis?",
"The URL you entered seems to be an external link. Do you want to add the required http:\/\/ prefix?": "Is nasc seachtrach \u00e9 an URL a chuir t\u00fa isteach. An bhfuil fonn ort an r\u00e9im\u00edr riachtanach http:\/\/ a chur leis?",
"Link list": "Liosta nascanna",
"Insert video": "Cuir f\u00edse\u00e1n isteach",
"Insert\/edit video": "Cuir f\u00edse\u00e1n isteach\/in eagar",
"Insert\/edit media": "Cuir me\u00e1n isteach\/in eagar",
"Alternative source": "Foinse mhalartach",
"Poster": "P\u00f3staer",
"Paste your embed code below:": "Greamaigh do ch\u00f3d leabaithe th\u00edos:",
"Embed": "Leabaigh",
"Media": "Me\u00e1in",
"Nonbreaking space": "Sp\u00e1s neamhbhristeach",
"Page break": "Briseadh leathanaigh",
"Paste as text": "Greamaigh mar th\u00e9acs",
"Preview": "R\u00e9amhamharc",
"Print": "Priont\u00e1il",
"Save": "S\u00e1bh\u00e1il",
"Find": "Aimsigh",
"Replace with": "Ionadaigh le",
"Replace": "Ionadaigh",
"Replace all": "Ionadaigh uile",
"Prev": "Siar",
"Next": "Ar aghaidh",
"Find and replace": "Aimsigh agus ionadaigh",
"Could not find the specified string.": "N\u00edor aims\u00edodh an teaghr\u00e1n.",
"Match case": "C\u00e1s-\u00edogair",
"Whole words": "Focail ioml\u00e1na",
"Spellcheck": "Seice\u00e1il an litri\u00fa",
"Ignore": "D\u00e9an neamhaird air",
"Ignore all": "D\u00e9an neamhaird orthu go l\u00e9ir",
"Finish": "Cr\u00edochnaigh",
"Add to Dictionary": "Cuir leis an bhFocl\u00f3ir \u00e9",
"Insert table": "Ions\u00e1igh t\u00e1bla",
"Table properties": "Air\u00edonna an t\u00e1bla",
"Delete table": "Scrios an t\u00e1bla",
"Cell": "Cill",
"Row": "R\u00f3",
"Column": "Col\u00fan",
"Cell properties": "Air\u00edonna na cille",
"Merge cells": "Cumaisc cealla",
"Split cell": "Roinn cill",
"Insert row before": "Ions\u00e1igh r\u00f3 os a chionn",
"Insert row after": "Ions\u00e1igh r\u00f3 faoi",
"Delete row": "Scrios an r\u00f3",
"Row properties": "Air\u00edonna an r\u00f3",
"Cut row": "Gearr an r\u00f3",
"Copy row": "C\u00f3ipe\u00e1il an r\u00f3",
"Paste row before": "Greamaigh r\u00f3 os a chionn",
"Paste row after": "Greamaigh r\u00f3 faoi",
"Insert column before": "Ions\u00e1igh col\u00fan ar chl\u00e9",
"Insert column after": "Ions\u00e1igh col\u00fan ar dheis",
"Delete column": "Scrios an col\u00fan",
"Cols": "Col\u00fain",
"Rows": "R\u00f3nna",
"Width": "Leithead",
"Height": "Airde",
"Cell spacing": "Sp\u00e1s\u00e1il ceall",
"Cell padding": "Stu\u00e1il ceall",
"Caption": "Fotheideal",
"Left": "Ar Chl\u00e9",
"Center": "Sa L\u00e1r",
"Right": "Ar Dheis",
"Cell type": "Cine\u00e1l na cille",
"Scope": "Sc\u00f3ip",
"Alignment": "Ail\u00edni\u00fa",
"H Align": "Ail\u00edni\u00fa C.",
"V Align": "Ail\u00edni\u00fa I.",
"Top": "Barr",
"Middle": "L\u00e1r",
"Bottom": "Bun",
"Header cell": "Cill cheannt\u00e1isc",
"Row group": "Gr\u00fapa r\u00f3nna",
"Column group": "Gr\u00fapa col\u00fan",
"Row type": "Cine\u00e1l an r\u00f3",
"Header": "Ceannt\u00e1sc",
"Body": "Corp",
"Footer": "Bunt\u00e1sc",
"Border color": "Dath na himl\u00edne",
"Insert template": "Ions\u00e1igh teimpl\u00e9ad",
"Templates": "Teimpl\u00e9id",
"Template": "Teimpl\u00e9ad",
"Text color": "Dath an t\u00e9acs",
"Background color": "Dath an ch\u00falra",
"Custom...": "Saincheap...",
"Custom color": "Dath saincheaptha",
"No color": "Gan dath",
"Table of Contents": "Cl\u00e1r na n\u00c1bhar",
"Show blocks": "Taispe\u00e1in blocanna",
"Show invisible characters": "Taispe\u00e1in carachtair dhofheicthe",
"Words: {0}": "Focail: {0}",
"{0} words": "{0} focal",
"File": "Comhad",
"Edit": "Eagar",
"Insert": "Ions\u00e1ig",
"View": "Amharc",
"Format": "Form\u00e1id",
"Table": "T\u00e1bla",
"Tools": "Uirlis\u00ed",
"Powered by {0}": "\u00c1 chumhacht\u00fa ag {0}",
"Rich Text Area. Press ALT-F9 for menu. Press ALT-F10 for toolbar. Press ALT-0 for help": "Limist\u00e9ar M\u00e9ith-Th\u00e9acs. Br\u00faigh ALT-F9 le haghaidh roghchl\u00e1ir, ALT-F10 le haghaidh barra uirlis\u00ed, agus ALT-0 le c\u00fanamh a fh\u00e1il"
});