tinymce.addI18n('hu_HU',{
"Redo": "Ism\u00e9t",
"Undo": "Visszavon\u00e1s",
"Cut": "Kiv\u00e1g\u00e1s",
"Copy": "M\u00e1sol\u00e1s",
"Paste": "Beilleszt\u00e9s",
"Select all": "Minden kijel\u00f6l\u00e9se",
"New document": "\u00daj dokumentum",
"Ok": "Rendben",
"Cancel": "M\u00e9gse",
"Visual aids": "Vizu\u00e1lis seg\u00e9deszk\u00f6z\u00f6k",
"Bold": "F\u00e9lk\u00f6v\u00e9r",
"Italic": "D\u0151lt",
"Underline": "Al\u00e1h\u00fazott",
"Strikethrough": "\u00c1th\u00fazott",
"Superscript": "Fels\u0151 index",
"Subscript": "Als\u00f3 index",
"Clear formatting": "Form\u00e1z\u00e1s t\u00f6rl\u00e9se",
"Align left": "Balra igaz\u00edt",
"Align center": "K\u00f6z\u00e9pre z\u00e1r",
"Align right": "Jobbra igaz\u00edt",
"Justify": "Sorkiz\u00e1r\u00e1s",
"Bullet list": "Felsorol\u00e1s",
"Numbered list": "Sz\u00e1moz\u00e1s",
"Decrease indent": "Beh\u00faz\u00e1s cs\u00f6kkent\u00e9se",
"Increase indent": "Beh\u00faz\u00e1s n\u00f6vel\u00e9se",
"Close": "Bez\u00e1r",
"Formats": "Form\u00e1tumok",
"Your browser doesn't support direct access to the clipboard. Please use the Ctrl+X\/C\/V keyboard shortcuts instead.": "A b\u00f6ng\u00e9sz\u0151d nem t\u00e1mogatja a k\u00f6zvetlen hozz\u00e1f\u00e9r\u00e9st a v\u00e1g\u00f3laphoz. K\u00e9rlek haszn\u00e1ld a Ctrl+X\/C\/V billenty\u0171ket.",
"Headers": "C\u00edmsorok",
"Header 1": "C\u00edmsor 1",
"Header 2": "C\u00edmsor 2",
"Header 3": "C\u00edmsor 3",
"Header 4": "C\u00edmsor 4",
"Header 5": "C\u00edmsor 5",
"Header 6": "C\u00edmsor 6",
"Headings": "Fejl\u00e9cek",
"Heading 1": "Fejl\u00e9c 1",
"Heading 2": "Fejl\u00e9c 2",
"Heading 3": "Fejl\u00e9c 3",
"Heading 4": "Fejl\u00e9c 4",
"Heading 5": "Fejl\u00e9c 5",
"Heading 6": "Fejl\u00e9c 6",
"Preformatted": "El\u0151form\u00e1zott",
"Div": "Div",
"Pre": "El\u0151form\u00e1zott",
"Code": "K\u00f3d",
"Paragraph": "Bekezd\u00e9s",
"Blockquote": "Id\u00e9zetblokk",
"Inline": "Sz\u00f6vegk\u00f6zi",
"Blocks": "Blokkok",
"Paste is now in plain text mode. Contents will now be pasted as plain text until you toggle this option off.": "Beilleszt\u00e9s mostant\u00f3l egyszer\u0171 sz\u00f6veg m\u00f3dban. A tartalmak mostant\u00f3l egyszer\u0171 sz\u00f6vegk\u00e9nt lesznek beillesztve, am\u00edg nem kapcsolod ki ezt az opci\u00f3t.",
"Font Family": "Bet\u0171t\u00edpus",
"Font Sizes": "Bet\u0171m\u00e9retek",
"Class": "Oszt\u00e1ly",
"Browse for an image": "K\u00e9p tall\u00f3z\u00e1sa",
"OR": "vagy",
"Drop an image here": "Dobj ide egy k\u00e9pet",
"Upload": "Felt\u00f6lt\u00e9s",
"Block": "Blokk",
"Align": "Igaz\u00edt\u00e1s",
"Default": "Alap\u00e9rtelmezett",
"Circle": "K\u00f6r",
"Disc": "Pont",
"Square": "N\u00e9gyzet",
"Lower Alpha": "Kisbet\u0171",
"Lower Greek": "Kis g\u00f6r\u00f6g sz\u00e1m",
"Lower Roman": "Kis r\u00f3mai sz\u00e1m",
"Upper Alpha": "Nagybet\u0171",
"Upper Roman": "Nagy r\u00f3mai sz\u00e1m",
"Anchor": "Horgony",
"Name": "N\u00e9v",
"Id": "Azonos\u00edt\u00f3",
"Id should start with a letter, followed only by letters, numbers, dashes, dots, colons or underscores.": "Az azonos\u00edt\u00f3nak bet\u0171vel kell kezd\u0151dnie, azut\u00e1n csak bet\u0171ket, sz\u00e1mokat, gondolatjeleket, pontokat, kett\u0151spontokat vagy al\u00e1h\u00faz\u00e1st tartalmazhat.",
"You have unsaved changes are you sure you want to navigate away?": "Nem mentett m\u00f3dos\u00edt\u00e1said vannak, biztos hogy el akarsz navig\u00e1lni?",
"Restore last draft": "Utols\u00f3 piszkozat vissza\u00e1ll\u00edt\u00e1sa",
"Special character": "Speci\u00e1lis karakter",
"Source code": "Forr\u00e1sk\u00f3d",
"Insert\/Edit code sample": "K\u00f3dminta besz\u00far\u00e1sa\/szerkeszt\u00e9se",
"Language": "Nyelv",
"Code sample": "K\u00f3d p\u00e9lda",
"Color": "Sz\u00edn",
"R": "R",
"G": "G",
"B": "B",
"Left to right": "Balr\u00f3l jobbra",
"Right to left": "Jobbr\u00f3l balra",
"Emoticons": "Vigyorok",
"Document properties": "Dokumentum tulajdons\u00e1gai",
"Title": "C\u00edm",
"Keywords": "Kulcsszavak",
"Description": "Le\u00edr\u00e1s",
"Robots": "Robotok",
"Author": "Szerz\u0151",
"Encoding": "K\u00f3dol\u00e1s",
"Fullscreen": "Teljes k\u00e9perny\u0151",
"Action": "M\u0171velet",
"Shortcut": "Parancsikon",
"Help": "S\u00fag\u00f3",
"Address": "C\u00edm",
"Focus to menubar": "F\u00f3kusz a men\u00fcre",
"Focus to toolbar": "F\u00f3kusz az eszk\u00f6zt\u00e1rra",
"Focus to element path": "F\u00f3kusz az elemek \u00fatvonal\u00e1ra",
"Focus to contextual toolbar": "F\u00f3kusz a k\u00f6rnyezetf\u00fcgg\u0151 eszk\u00f6zt\u00e1rra",
"Insert link (if link plugin activated)": "Hivatkoz\u00e1s besz\u00far\u00e1sa (ha a hivatkoz\u00e1s b\u0151v\u00edtm\u00e9ny enged\u00e9lyezett)",
"Save (if save plugin activated)": "Ment\u00e9s (ha a ment\u00e9s b\u0151v\u00edtm\u00e9ny enged\u00e9lyezett)",
"Find (if searchreplace plugin activated)": "Keres\u00e9s (ha a keres\u00e9s \u00e9s csere b\u0151v\u00edtm\u00e9ny enged\u00e9lyezett)",
"Plugins installed ({0}):": "Telep\u00edtett b\u0151v\u00edtm\u00e9nyek ({0}):",
"Premium plugins:": "Pr\u00e9mium b\u0151v\u00edtm\u00e9nyek:",
"Learn more...": "Tudj meg t\u00f6bbet...",
"You are using {0}": "Haszn\u00e1latban: {0}",
"Plugins": "Pluginek",
"Handy Shortcuts": "Hasznos linkek",
"Horizontal line": "V\u00edzszintes vonal",
"Insert\/edit image": "K\u00e9p beilleszt\u00e9se\/szerkeszt\u00e9se",
"Image description": "K\u00e9p le\u00edr\u00e1sa",
"Source": "Forr\u00e1s",
"Dimensions": "M\u00e9retek",
"Constrain proportions": "M\u00e9retar\u00e1ny",
"General": "\u00c1ltal\u00e1nos",
"Advanced": "Halad\u00f3",
"Style": "St\u00edlus",
"Vertical space": "Vertik\u00e1lis hely",
"Horizontal space": "Horizont\u00e1lis hely",
"Border": "Szeg\u00e9ly",
"Insert image": "K\u00e9p beilleszt\u00e9se",
"Image": "K\u00e9p",
"Image list": "K\u00e9p lista",
"Rotate counterclockwise": "Forgat\u00e1s az \u00f3ramutat\u00f3 j\u00e1r\u00e1s\u00e1val ellent\u00e9tesen",
"Rotate clockwise": "Forgat\u00e1s az \u00f3ramutat\u00f3 j\u00e1r\u00e1s\u00e1val megegyez\u0151en",
"Flip vertically": "F\u00fcgg\u0151leges t\u00fckr\u00f6z\u00e9s",
"Flip horizontally": "V\u00edzszintes t\u00fckr\u00f6z\u00e9s",
"Edit image": "K\u00e9p szerkeszt\u00e9se",
"Image options": "K\u00e9p be\u00e1ll\u00edt\u00e1sok",
"Zoom in": "Nagy\u00edt\u00e1s",
"Zoom out": "Kicsiny\u00edt\u00e9s",
"Crop": "K\u00e9p v\u00e1g\u00e1s",
"Resize": "\u00c1tm\u00e9retez\u00e9s",
"Orientation": "K\u00e9p t\u00e1jol\u00e1s",
"Brightness": "F\u00e9nyer\u0151",
"Sharpen": "\u00c9less\u00e9g",
"Contrast": "Kontraszt",
"Color levels": "Sz\u00ednszint",
"Gamma": "Gamma",
"Invert": "Inverz k\u00e9p",
"Apply": "Ment\u00e9s",
"Back": "Vissza",
"Insert date\/time": "D\u00e1tum\/id\u0151 beilleszt\u00e9se",
"Date\/time": "D\u00e1tum\/id\u0151",
"Insert link": "Hivatkoz\u00e1s beilleszt\u00e9se",
"Insert\/edit link": "Hivatkoz\u00e1s beilleszt\u00e9se\/szerkeszt\u00e9se",
"Text to display": "Megjelen\u0151 sz\u00f6veg",
"Url": "Url",
"Target": "C\u00e9l",
"None": "Nincs",
"New window": "\u00daj ablak",
"Remove link": "Hivatkoz\u00e1s t\u00f6rl\u00e9se",
"Anchors": "Horgonyok",
"Link": "Hivatkoz\u00e1s",
"Paste or type a link": "Hivatkoz\u00e1s be\u00edr\u00e1sa vagy beilleszt\u00e9se",
"The URL you entered seems to be an email address. Do you want to add the required mailto: prefix?": "A megadott URL email c\u00edmnek t\u0171nik. Szeretn\u00e9d hozz\u00e1adni a sz\u00fcks\u00e9ges mailto: el\u0151tagot?",
"The URL you entered seems to be an external link. Do you want to add the required http:\/\/ prefix?": "A megadott URL k\u00fcls\u0151 c\u00edmnek t\u0171nik. Szeretn\u00e9d hozz\u00e1adni a sz\u00fcks\u00e9ges http:\/\/ el\u0151tagot?",
"Link list": "Hivatkoz\u00e1slista",
"Insert video": "Vide\u00f3 beilleszt\u00e9se",
"Insert\/edit video": "Vide\u00f3 beilleszt\u00e9se\/szerkeszt\u00e9se",
"Insert\/edit media": "M\u00e9dia besz\u00far\u00e1sa\/beilleszt\u00e9se",
"Alternative source": "Alternat\u00edv forr\u00e1s",
"Poster": "El\u0151n\u00e9zeti k\u00e9p",
"Paste your embed code below:": "Illeszd be a be\u00e1gyaz\u00f3 k\u00f3dot alulra:",
"Embed": "Be\u00e1gyaz\u00e1s",
"Media": "M\u00e9dia",
"Nonbreaking space": "Nem t\u00f6rhet\u0151 sz\u00f3k\u00f6z",
"Page break": "Oldalt\u00f6r\u00e9s",
"Paste as text": "Beilleszt\u00e9s sz\u00f6vegk\u00e9nt",
"Preview": "El\u0151n\u00e9zet",
"Print": "Nyomtat\u00e1s",
"Save": "Ment\u00e9s",
"Find": "Keres\u00e9s",
"Replace with": "Csere erre",
"Replace": "Csere",
"Replace all": "Az \u00f6sszes cser\u00e9je",
"Prev": "El\u0151z\u0151",
"Next": "K\u00f6vetkez\u0151",
"Find and replace": "Keres\u00e9s \u00e9s csere",
"Could not find the specified string.": "A be\u00edrt kifejez\u00e9s nem tal\u00e1lhat\u00f3.",
"Match case": "Kis \u00e9s nagybet\u0171k megk\u00fcl\u00f6nb\u00f6ztet\u00e9se",
"Whole words": "Csak ha ez a teljes sz\u00f3",
"Spellcheck": "Helyes\u00edr\u00e1s ellen\u0151rz\u00e9s",
"Ignore": "Figyelmen k\u00edv\u00fcl hagy",
"Ignore all": "Mindent figyelmen k\u00edv\u00fcl hagy",
"Finish": "Befejez\u00e9s",
"Add to Dictionary": "Sz\u00f3t\u00e1rhoz ad",
"Insert table": "T\u00e1bl\u00e1zat beilleszt\u00e9se",
"Table properties": "T\u00e1bl\u00e1zat tulajdons\u00e1gok",
"Delete table": "T\u00e1bl\u00e1zat t\u00f6rl\u00e9se",
"Cell": "Cella",
"Row": "Sor",
"Column": "Oszlop",
"Cell properties": "Cella tulajdons\u00e1gok",
"Merge cells": "Cell\u00e1k egyes\u00edt\u00e9se",
"Split cell": "Cell\u00e1k sz\u00e9tv\u00e1laszt\u00e1sa",
"Insert row before": "Sor besz\u00far\u00e1sa el\u00e9",
"Insert row after": "Sor besz\u00far\u00e1sa m\u00f6g\u00e9",
"Delete row": "Sor t\u00f6rl\u00e9se",
"Row properties": "Sor tulajdons\u00e1gai",
"Cut row": "Sor kiv\u00e1g\u00e1sa",
"Copy row": "Sor m\u00e1sol\u00e1sa",
"Paste row before": "Sor beilleszt\u00e9se el\u00e9",
"Paste row after": "Sor beilleszt\u00e9se m\u00f6g\u00e9",
"Insert column before": "Oszlop besz\u00far\u00e1sa el\u00e9",
"Insert column after": "Oszlop besz\u00far\u00e1sa m\u00f6g\u00e9",
"Delete column": "Oszlop t\u00f6rl\u00e9se",
"Cols": "Oszlopok",
"Rows": "Sorok",
"Width": "Sz\u00e9less\u00e9g",
"Height": "Magass\u00e1g",
"Cell spacing": "Cell\u00e1k t\u00e1vols\u00e1ga",
"Cell padding": "Cella m\u00e9rete",
"Caption": "Felirat",
"Left": "Bal",
"Center": "K\u00f6z\u00e9p",
"Right": "Jobb",
"Cell type": "Cella t\u00edpusa",
"Scope": "Hat\u00f3k\u00f6r",
"Alignment": "Igaz\u00edt\u00e1s",
"H Align": "V\u00edzszintes igaz\u00edt\u00e1s",
"V Align": "F\u00fcgg\u0151leges igaz\u00edt\u00e1s",
"Top": "Fel\u00fcl",
"Middle": "K\u00f6z\u00e9pen",
"Bottom": "Alul",
"Header cell": "Fejl\u00e9c cella",
"Row group": "Sor csoport",
"Column group": "Oszlop csoport",
"Row type": "Sor t\u00edpus",
"Header": "Fejl\u00e9c",
"Body": "Sz\u00f6vegt\u00f6rzs",
"Footer": "L\u00e1bl\u00e9c",
"Border color": "Szeg\u00e9ly sz\u00edne",
"Insert template": "Sablon beilleszt\u00e9se",
"Templates": "Sablonok",
"Template": "Sablon",
"Text color": "Sz\u00f6veg sz\u00edne",
"Background color": "H\u00e1tt\u00e9r sz\u00edn",
"Custom...": "Egy\u00e9ni...",
"Custom color": "Egy\u00e9ni sz\u00edn",
"No color": "Nincs sz\u00edn",
"Table of Contents": "Tartalomjegyz\u00e9k",
"Show blocks": "Blokkok mutat\u00e1sa",
"Show invisible characters": "L\u00e1thatatlan karakterek mutat\u00e1sa",
"Words: {0}": "Szavak: {0}",
"{0} words": "{0} sz\u00f3",
"File": "F\u00e1jl",
"Edit": "Szerkeszt\u00e9s",
"Insert": "Beilleszt\u00e9s",
"View": "N\u00e9zet",
"Format": "Form\u00e1tum",
"Table": "T\u00e1bl\u00e1zat",
"Tools": "Eszk\u00f6z\u00f6k",
"Powered by {0}": "\u00dczemelteti: {0}",
"Rich Text Area. Press ALT-F9 for menu. Press ALT-F10 for toolbar. Press ALT-0 for help": "Rich Text ter\u00fclet. Nyomj ALT-F9-et a men\u00fch\u00f6z. Nyomj ALT-F10-et az eszk\u00f6zt\u00e1rhoz. Nyomj ALT-0-t a s\u00fag\u00f3hoz"
});