tinymce.addI18n('sr',{
"Redo": "Napred",
"Undo": "Nazad",
"Cut": "Iseci",
"Copy": "Kopiraj",
"Paste": "Nalepi",
"Select all": "Obele\u017ei sve",
"New document": "Novi dokument",
"Ok": "Ok",
"Cancel": "Opozovi",
"Visual aids": "Vizuelna pomagala",
"Bold": "Podebljan",
"Italic": "isko\u0161en",
"Underline": "Podvu\u010den",
"Strikethrough": "Precrtan",
"Superscript": "Natpis",
"Subscript": "Potpisan",
"Clear formatting": "Brisanje formatiranja",
"Align left": "Poravnano levo",
"Align center": "Poravnano centar",
"Align right": "Poravnano  desno",
"Justify": "Poravnanje",
"Bullet list": "Lista nabrajanja",
"Numbered list": "Numerisana lista",
"Decrease indent": "Smanji uvla\u010denje",
"Increase indent": "Pove\u0107aj uvla\u010denje",
"Close": "Zatvori",
"Formats": "Formatiraj",
"Your browser doesn't support direct access to the clipboard. Please use the Ctrl+X\/C\/V keyboard shortcuts instead.": "Va\u0161 pretra\u017eiva\u010d nepodr\u017eava direktan pristup prenosu.Koristite Ctrl+X\/C\/V pre\u010dice na tastaturi",
"Headers": "Zaglavlje",
"Header 1": "Zaglavlje 1",
"Header 2": "Zaglavlje 2",
"Header 3": "Zaglavlje 3",
"Header 4": "Zaglavlje 4",
"Header 5": "Zaglavlje 5",
"Header 6": "Zaglavlje 6",
"Headings": "Naslovi",
"Heading 1": "Naslov 1",
"Heading 2": "Naslov 2",
"Heading 3": "Naslov 3",
"Heading 4": "Naslov 4",
"Heading 5": "Naslov 5",
"Heading 6": "Naslov 6",
"Preformatted": "Formatirano",
"Div": "Div",
"Pre": "Pre",
"Code": "Kod",
"Paragraph": "Paragraf",
"Blockquote": "Navodnici",
"Inline": "U liniji",
"Blocks": "Blokovi",
"Paste is now in plain text mode. Contents will now be pasted as plain text until you toggle this option off.": "Nalepiti je sada u obi\u010dnom text modu.Sadr\u017eaj \u0107e biti nalepljen kao obi\u010dan tekst dok ne ugasite ovu opciju.",
"Font Family": "Vrsta fonta",
"Font Sizes": "Veli\u010dine fontova",
"Class": "Klasa",
"Browse for an image": "Prona\u0111i sliku",
"OR": "ili",
"Drop an image here": "Prevuci sliku ovde",
"Upload": "Po\u0161alji",
"Block": "Blok",
"Align": "Poravnaj",
"Default": "Podrazumevano",
"Circle": "Krug",
"Disc": "Disk",
"Square": "Kvadrat",
"Lower Alpha": "Donja Alpha",
"Lower Greek": "Ni\u017ei gr\u010dki",
"Lower Roman": "Donji Roman",
"Upper Alpha": "Gornji Alpha",
"Upper Roman": "Gornji Roman",
"Anchor": "Sidro",
"Name": "Ime",
"Id": "id",
"Id should start with a letter, followed only by letters, numbers, dashes, dots, colons or underscores.": "Id treba da po\u010dinje slovom, pra\u0107eno samo slovima, brojevima, crticama, ta\u010dkama, dvota\u010dkom ili donjim crtama",
"You have unsaved changes are you sure you want to navigate away?": "Imate nesa\u010duvane promene dali ste sigurni da \u017eelite da iza\u0111ete?",
"Restore last draft": "Vrati  poslednji nacrt",
"Special character": "Specijalni karakter",
"Source code": "Izvorni kod",
"Insert\/Edit code sample": "Dodaj\/Izmeni primer koda",
"Language": "Jezik",
"Code sample": "Primer koda",
"Color": "Boja",
"R": "R",
"G": "G",
"B": "B",
"Left to right": "Sa leve na desnu",
"Right to left": "Sa desne na levu",
"Emoticons": "Smajliji",
"Document properties": "Postavke dokumenta",
"Title": "Naslov",
"Keywords": "Klju\u010dne re\u010di",
"Description": "Opis",
"Robots": "Roboti",
"Author": "Autor",
"Encoding": "Kodiranje",
"Fullscreen": "Pun ekran",
"Action": "Akcija",
"Shortcut": "Pre\u010dica",
"Help": "Pomo\u0107",
"Address": "Adresa",
"Focus to menubar": "Fokus na meni",
"Focus to toolbar": "Fokus na traku sa alatima",
"Focus to element path": "Fokus na putanju elementa",
"Focus to contextual toolbar": "Fokus na kontekstualnu traku alata",
"Insert link (if link plugin activated)": "Dodaj link (ukoliko je link dodatak aktiviran)",
"Save (if save plugin activated)": "Sa\u010duvaj (ukoliko je sa\u010duvaj dodatak aktiviran)",
"Find (if searchreplace plugin activated)": "Prona\u0111i (ako je dodatak pretrage i zamene aktiviran)",
"Plugins installed ({0}):": "Dodataka instalirano ({0}):",
"Premium plugins:": "Premium dodaci",
"Learn more...": "Saznaj vi\u0161e",
"You are using {0}": "Koristite {0}",
"Plugins": "Dadaci",
"Handy Shortcuts": "Prakti\u010dne pre\u010dice",
"Horizontal line": "Horizontalna linija",
"Insert\/edit image": "Ubaci\/Promeni sliku",
"Image description": "Opis slike",
"Source": "Izvor",
"Dimensions": "Dimenzije",
"Constrain proportions": "Ograni\u010dene proporcije",
"General": "Op\u0161te",
"Advanced": "Napredno",
"Style": "Stil",
"Vertical space": "Vertikalni razmak",
"Horizontal space": "Horizontalni razmak",
"Border": "Okvir",
"Insert image": "Ubaci sliku",
"Image": "Slika",
"Image list": "Lista slika",
"Rotate counterclockwise": "Rotiraj levo",
"Rotate clockwise": "Rotiraj desno",
"Flip vertically": "Okreni vertikalno",
"Flip horizontally": "Okreni horizontalno",
"Edit image": "Izmeni sliku",
"Image options": "Opcije slike",
"Zoom in": "Uve\u0107aj",
"Zoom out": "Umanji",
"Crop": "Izeci",
"Resize": "Promeni veli\u010dinu",
"Orientation": "Orijentacija",
"Brightness": "Osvetljenje",
"Sharpen": "Izo\u0161travanje",
"Contrast": "Kontrast",
"Color levels": "Nivo boja",
"Gamma": "Gama",
"Invert": "Izokreni",
"Apply": "Primeni",
"Back": "Nazad",
"Insert date\/time": "Ubaci datum\/vreme",
"Date\/time": "Datum\/vreme",
"Insert link": "Ubaci vezu",
"Insert\/edit link": "Ubaci\/promeni vezu",
"Text to display": "Tekst za prikaz",
"Url": "Url",
"Target": "Meta",
"None": "Ni\u0161ta",
"New window": "Novi prozor",
"Remove link": "Ukloni link",
"Anchors": "sidro",
"Link": "Link",
"Paste or type a link": "Nalepi ili ukucaj link",
"The URL you entered seems to be an email address. Do you want to add the required mailto: prefix?": "Izgleda da je URL koji ste uneli email adresa. Da li \u017eelite da dodate zahtevani mailto: prefiks?",
"The URL you entered seems to be an external link. Do you want to add the required http:\/\/ prefix?": "Izgleda da je URL koji ste uneli spolja\u0161nja veza. Da li \u017eelite da dodate zahtevani http:\/\/ prefiks?",
"Link list": "Lista veza",
"Insert video": "Ubaci video",
"Insert\/edit video": "Ubaci\/promeni video",
"Insert\/edit media": "Ubaci\/izmeni mediju",
"Alternative source": "Alternativni izvor",
"Poster": "Poster",
"Paste your embed code below:": "Nalepite ugra\u0111eni kod ispod:",
"Embed": "Ugra\u0111eno",
"Media": "Medija",
"Nonbreaking space": "bez ramaka",
"Page break": "Lomljenje stranice",
"Paste as text": "Nalepi kao tekst",
"Preview": "Pregled",
"Print": "\u0160tampanje",
"Save": "Sa\u010duvati",
"Find": "Na\u0111i",
"Replace with": "Zameni sa",
"Replace": "Zameni",
"Replace all": "Zameni sve",
"Prev": "Prethodni",
"Next": "Slede\u0107i",
"Find and replace": "Na\u0111i i zameni",
"Could not find the specified string.": "Nije mogu\u0107e prona\u0107i navedeni niz.",
"Match case": "Predmet za upore\u0111ivanje",
"Whole words": "Cele re\u010di",
"Spellcheck": "Provera pravopisa",
"Ignore": "ignori\u0161i",
"Ignore all": "Ignori\u0161i sve",
"Finish": "Kraj",
"Add to Dictionary": "Dodaj u re\u010dnik",
"Insert table": "ubaci tabelu",
"Table properties": "Postavke tabele",
"Delete table": "Obri\u0161i tabelu",
"Cell": "\u0106elija",
"Row": "Red",
"Column": "Kolona",
"Cell properties": "Postavke \u0107elije",
"Merge cells": "Spoji \u0107elije",
"Split cell": "Razdvoji \u0107elije",
"Insert row before": "Ubaci red pre",
"Insert row after": "Ubaci red posle",
"Delete row": "Obri\u0161i red",
"Row properties": "Postavke reda",
"Cut row": "Iseci red",
"Copy row": "Kopiraj red",
"Paste row before": "Nalepi red pre",
"Paste row after": "Nalepi red posle",
"Insert column before": "Ubaci kolonu pre",
"Insert column after": "Ubaci kolonu posle",
"Delete column": "Obri\u0161i kolonu",
"Cols": "Kolone",
"Rows": "Redovi",
"Width": "\u0160irina",
"Height": "Visina",
"Cell spacing": "Prostor \u0107elije",
"Cell padding": "Razmak \u0107elije",
"Caption": "Natpis",
"Left": "Levo",
"Center": "Centar",
"Right": "Desno",
"Cell type": "Tip \u0107elije",
"Scope": "Obim",
"Alignment": "Svrstavanje",
"H Align": "Horizontalno poravnanje",
"V Align": "Vertikalno poravnanje",
"Top": "Vrh",
"Middle": "Sredina",
"Bottom": "Podno\u017eje",
"Header cell": "Visina \u0107elije",
"Row group": "Grupa reda",
"Column group": "Grupa kolone",
"Row type": "Tip reda",
"Header": "Zaglavlje",
"Body": "Telo",
"Footer": "Podno\u017eje",
"Border color": "Boja ivice",
"Insert template": "Ubaci \u0161ablon",
"Templates": "\u0160abloni",
"Template": "\u0160ablon",
"Text color": "Boja tekst",
"Background color": "Boja pozadine",
"Custom...": "Posebno...",
"Custom color": "Posebna boja",
"No color": "Bez boje",
"Table of Contents": "Tabela sadr\u017eaja",
"Show blocks": "Prikaz blokova",
"Show invisible characters": "Prika\u017ei nevidljive karaktere",
"Words: {0}": "Re\u010di:{0}",
"{0} words": "{0} re\u010di",
"File": "Datoteka",
"Edit": "Ure\u0111ivanje",
"Insert": "Umetni",
"View": "Prikaz",
"Format": "Format",
"Table": "Tabela",
"Tools": "Alatke",
"Powered by {0}": "Pokre\u0107e ga {0}",
"Rich Text Area. Press ALT-F9 for menu. Press ALT-F10 for toolbar. Press ALT-0 for help": "Oboga\u0107en tekst. Pritisni te ALT-F9 za meni.Pritisnite ALT-F10 za traku sa alatkama.Pritisnite ALT-0 za pomo\u0107"
});